@@ -111,9 +111,15 @@ class BatteryChecker(IntervalModule):
         ("alert", "Display a libnotify-notification on low battery"),
         "alert_percentage", "alert_format_title", "alert_format_body", "alert_percentage",
         "path",
+        ("status", "A dictionary mapping ('DIS', 'CHR', 'FULL') to alternative names"),
     )
     battery_ident = "BAT0"
     format = "{status} {remaining_hm}"
+    status = {
+        "CHR": "CHR",
+        "DIS": "DIS",
+        "FULL": "FULL",
+    }
     
     alert = False
     alert_percentage = 10
@@ -155,7 +161,7 @@ class BatteryChecker(IntervalModule):
         else:
             fdict["status"] = "FULL"
 
-        if self.alert and fdict["percentage"] <= self.alert_percentage:
+        if self.alert and fdict["status"] == "DIS" and fdict["percentage"] <= self.alert_percentage:
             display_notification(
                 title=self.alert_format_title.format(**fdict),
                 body=self.alert_format_body.format(**fdict),
@@ -163,6 +169,8 @@ class BatteryChecker(IntervalModule):
                 urgency=2,
             )
 
+        fdict["status"] = self.status[fdict["status"]]
+
         self.output = {
             "full_text": self.format.format(**fdict).strip(),
             "instance": self.battery_ident,
